@@ -1,13 +1,19 @@
+"""
+Local stores implement the API for a store in Kodexa but allow you to work in an offline model.
+
+This is useful for unit testing or working locally.
+"""
+
 import logging
 import os
 import shutil
 from pathlib import Path
-from typing import List, Optional, Dict
+from typing import Any, Dict, List, Optional
 
 import jsonpickle
 
-from kodexa.model import DocumentFamily, DocumentStore, Document, ContentObject, ModelStore, Store
-from kodexa.model.document_families import ContentEvent, DocumentTransition
+from kodexa.model import ContentEvent, ContentObject, Document, DocumentFamily, DocumentStore, DocumentTransition, \
+    ModelStore, Store
 
 logger = logging.getLogger('kodexa.stores')
 
@@ -59,7 +65,7 @@ class LocalDocumentStore(DocumentStore):
         if self.index >= len(self.metastore):
             raise StopIteration
         content_object = self.metastore[self.index].content_objects[-1]
-        document = self.get_document_by_content_object(content_object)
+        document = self.get_document_by_content_object(self.metastore[self.index], content_object)
 
         from kodexa.model.model import ContentObjectReference
         content_object_reference = ContentObjectReference(content_object, self, document, self.metastore[self.index])
@@ -70,8 +76,8 @@ class LocalDocumentStore(DocumentStore):
         """
 
         Args:
-          document: Document: 
-          context: 
+          document: Document:
+          context:
 
         Returns:
 
@@ -90,7 +96,7 @@ class LocalDocumentStore(DocumentStore):
         """
 
         Args:
-          listener: 
+          listener:
 
         Returns:
 
@@ -101,7 +107,7 @@ class LocalDocumentStore(DocumentStore):
         """
 
         Args:
-          content_event: ContentEvent: 
+          content_event: ContentEvent:
 
         Returns:
 
@@ -122,7 +128,7 @@ class LocalDocumentStore(DocumentStore):
         """
 
         Args:
-          document: Document: 
+          document: Document:
 
         Returns:
 
@@ -147,7 +153,7 @@ class LocalDocumentStore(DocumentStore):
         """
 
         Args:
-          uuid: str: 
+          uuid: str:
 
         Returns:
 
@@ -164,7 +170,7 @@ class LocalDocumentStore(DocumentStore):
 
         Args:
           path: return:
-          path: str: 
+          path: str:
 
         Returns:
 
@@ -176,11 +182,16 @@ class LocalDocumentStore(DocumentStore):
                 return Document.from_kdxa(os.path.join(self.store_path, family.get_latest_content().id) + ".kdxa")
         return None
 
+    def query_families(self, query: str = "*", page: int = 1, page_size: int = 100) -> List[DocumentFamily]:
+
+        # TODO implement query
+        return self.metastore
+
     def get_family_by_path(self, path: str) -> Optional[DocumentFamily]:
         """
 
         Args:
-          path: str: 
+          path: str:
 
         Returns:
 
@@ -194,14 +205,14 @@ class LocalDocumentStore(DocumentStore):
         """
 
         Args:
-          path: str: 
+          path: str:
 
         Returns:
 
         """
         for family in self.metastore:
             if family.path == path:
-                return self.get_document_by_content_object(family.content_objects[-1])
+                return self.get_document_by_content_object(family, family.content_objects[-1])
         return None
 
     def list_objects(self) -> List[ContentObject]:
@@ -214,7 +225,7 @@ class LocalDocumentStore(DocumentStore):
 
     def count(self) -> int:
         """Returns a count of the number of document families
-        
+
         :return:
 
         Args:
@@ -228,7 +239,7 @@ class LocalDocumentStore(DocumentStore):
         """
 
         Args:
-          path: str: 
+          path: str:
 
         Returns:
 
@@ -236,14 +247,14 @@ class LocalDocumentStore(DocumentStore):
         document = Document.from_kdxa(path)
         self.put(document.uuid, document)
 
-    def add_related_document_to_family(self, document_family_id: str, document_relationship: DocumentTransition,
+    def add_related_document_to_family(self, document_family_id: str, transition: DocumentTransition,
                                        document: Document):
         """
 
         Args:
-          document_family_id: str: 
-          document_relationship: DocumentTransition:
-          document: Document: 
+          document_family_id: str:
+          transition: DocumentTransition:
+          document: Document:
 
         Returns:
 
@@ -251,28 +262,31 @@ class LocalDocumentStore(DocumentStore):
         self.read_metastore()
         for family in self.metastore:
             if family.id == document_family_id:
-                family.add_document(document, document_relationship)
+                family.add_document(document, transition)
 
-    def get_document_by_content_object(self, content_object: ContentObject) -> Document:
+    def get_document_by_content_object(self, document_family: DocumentFamily,
+                                       content_object: ContentObject) -> Document:
         """
 
         Args:
-          content_object: ContentObject: 
+          document_family (DocumentFamily): The document family
+          content_object (ContentObject): The content object
 
         Returns:
 
         """
         return Document.from_kdxa(os.path.join(self.store_path, content_object.id) + ".kdxa")
 
-    def put(self, path: str, document: Document):
+    def put(self, path: str, document: Document, force_replace: bool = False) -> DocumentFamily:
         """
 
         Args:
-          path: str: 
-          document: Document: 
+          path (str): The path to the document family
+          document (Document): The document you wish to upload
+          force_replace (bool): True if you want to delete the family in this path first
 
         Returns:
-
+            The new document family instance
         """
 
         # We can only add a document if it doesn't already exist as a family
@@ -287,7 +301,11 @@ class LocalDocumentStore(DocumentStore):
             # Notify the listeners
             self.notify_listeners(new_event)
 
-        return self.get_family_by_path(path)
+        document_family = self.get_family_by_path(path)
+        if document_family is not None:
+            return document_family
+        else:
+            raise Exception("Unable to get document family?")
 
     def exists(self, document):
         """Look to see if we have document with the same original path and original filename
@@ -332,38 +350,36 @@ class LocalModelStore(ModelStore):
             }
         }
 
-    def get(self, object_path: str):
+    def get_native(self, path: str):
         """
 
         Args:
-          object_path: str: 
+          path: str:
 
         Returns:
 
         """
-        if Path(os.path.join(self.store_path, object_path)).is_file():
-            return open(os.path.join(self.store_path, object_path), 'rb')
+        if Path(os.path.join(self.store_path, path)).is_file():
+            return open(os.path.join(self.store_path, path), 'rb')
         else:
             return None
 
-    def put(self, object_path: str, content):
+    def put_native(self, path: str, content: Any):
         """
 
         Args:
-          object_path: str: 
-          content: 
-
+          path (str): The path to the native file
+          content (Any): The content to store
         Returns:
 
         """
-        path = Path(object_path)
-        with open(os.path.join(self.store_path, path), 'wb') as object_file:
-            object_file.write(content)
+        with open(os.path.join(self.store_path, path), 'wb') as file:
+            file.write(content)
 
 
 class TableDataStore(Store):
     """Stores data as a list of lists that can represent a table.
-    
+
     This is a good store when you are capturing nested or tabular data.
 
     Args:
@@ -427,7 +443,7 @@ class TableDataStore(Store):
         """
 
         Args:
-          pipeline_context: 
+          pipeline_context:
 
         Returns:
 
@@ -447,7 +463,7 @@ class TableDataStore(Store):
 
     def count(self):
         """Returns the number of rows in the store
-        
+
         :return: number of rows
 
         Args:
@@ -474,7 +490,7 @@ class TableDataStore(Store):
         """
 
         Args:
-          store_dict: 
+          store_dict:
 
         Returns:
 
