@@ -1,11 +1,17 @@
+"""
+Remote stores allow you to interact with an instance of the Kodexa platform
+"""
+
 import json
 import logging
 from json import JSONDecodeError
-from typing import List, Dict, Optional
+from typing import Any, List, Optional
 
 import requests
+from requests import Response
 
-from kodexa.model import Document, DocumentStore, RemoteStore, ModelStore, ContentObject
+from kodexa.model import ContentObject, Document, DocumentFamily, DocumentStore, DocumentTransition, ModelStore, \
+    RemoteStore
 from kodexa.stores.local import LocalModelStore, TableDataStore
 
 logger = logging.getLogger('kodexa.stores')
@@ -14,7 +20,9 @@ logger = logging.getLogger('kodexa.stores')
 class RemoteTableDataStore(RemoteStore):
     """ """
 
-    def __init__(self, ref: str, columns: List[str] = []):
+    def __init__(self, ref: str, columns=None):
+        if columns is None:
+            columns = []
         self.ref = ref
         self.columns = columns
 
@@ -26,7 +34,7 @@ class RemoteTableDataStore(RemoteStore):
         """
 
         Args:
-          table: str: 
+          table: str:
 
         Returns:
 
@@ -40,7 +48,7 @@ class RemoteTableDataStore(RemoteStore):
         """
 
         Args:
-          table: str: 
+          table: str:
 
         Returns:
 
@@ -87,7 +95,7 @@ class RemoteTableDataStore(RemoteStore):
         """
 
         Args:
-          table: str: 
+          table: str:
           page_number: int:  (Default value = 1)
           page_size:  (Default value = 5000)
 
@@ -117,7 +125,7 @@ class RemoteTableDataStore(RemoteStore):
         """
 
         Args:
-          rows: 
+          rows:
 
         Returns:
 
@@ -141,7 +149,7 @@ class RemoteTableDataStore(RemoteStore):
         """
 
         Args:
-          row: 
+          row:
 
         Returns:
 
@@ -169,40 +177,6 @@ class RemoteTableDataStore(RemoteStore):
             raise Exception("Unable to post rows to remote store [" + doc.text + "], response " + str(doc.status_code))
 
 
-class RemoteDictDataStore(RemoteStore):
-    """ """
-
-    def __init__(self, ref: str):
-        self.ref: str = ref
-
-    def get_ref(self):
-        """ """
-        return self.ref
-
-    def add(self, dict):
-        """Writes a dict to the Data Store
-
-        Args:
-          dict: the dict to add to the store
-
-        Returns:
-
-        """
-        from kodexa import KodexaPlatform
-
-        url = f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/dictionaries"
-        logger.debug(f"Uploading dictionaries to store {url}")
-        doc = requests.post(
-            url,
-            [{'data': dict}],
-            headers={"x-access-token": KodexaPlatform.get_access_token()})
-        if doc.status_code == 200:
-            return
-        else:
-            logger.error("Unable to post dict to remote store [" + doc.text + "], response " + str(doc.status_code))
-            raise Exception("Unable to post dict to remote store [" + doc.text + "], response " + str(doc.status_code))
-
-
 class DataStoreHelper:
     """A small helper that can convert a dictionary back into a store
     type
@@ -221,7 +195,8 @@ class DataStoreHelper:
           dict: doc_dict: A dictionary representation of a Kodexa Document.
 
         Returns:
-          TableDataStore, DictDataStore, or None: A TableDataStore or DictDataStore - driven from 'type' in doc_dict.  If 'type' is not present or does not align with one of these two types, None is returend.
+          TableDataStore, DictDataStore, or None: A TableDataStore or DictDataStore - driven from 'type' in doc_dict.
+          If 'type' is not present or does not align with one of these two types, None is returend.
 
         >>> Document.from_dict(doc_dict)
         """
@@ -245,34 +220,31 @@ class DataStoreHelper:
             else:
                 return None
         else:
-            logger.info(f"Unknown store")
+            logger.info("Unknown store")
             return None
 
 
 class RemoteDocumentStore(DocumentStore, RemoteStore):
-    """ """
+    """
+    Remote Document Stores provide you with all the capabilities of Document storage and relationships
+    in an instance of the Kodexa platform
+    """
 
-    def __init__(self, ref: str, query: str = "*"):
+    def __init__(self, ref: str):
         self.ref: str = ref
-        self.objects: Optional[List[Dict]] = None
-        self.page = 1
-        self.query_string: str = query
 
     def get_name(self):
         """The name of the connector
-        
-        :return: 'document-store'
-
-        Args:
 
         Returns:
+            The name of the document store
 
         """
-        return "document-store"
+        return self.get_ref()
 
     def get_ref(self) -> str:
         """Get the reference to the store on the platform (i.e. kodexa/my-store:1.1.0)
-        
+
         :return: The reference
 
         Args:
@@ -283,287 +255,162 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
         return self.ref
 
     def to_dict(self):
-        """ """
+        """
+        Convert the document store to its metadata dictionary
+
+        Returns:
+            A dictionary representing the metadata for the store
+        """
         return {
             "type": "DOCUMENT",
             "ref": self.ref
         }
 
-    def get(self, document_id: str) -> Optional[Document]:
-        """Get the document from the remote store using the document's ID
-
-        Args:
-          document_id: the ID of the document
-          document_id: str: 
-
-        Returns:
-          Optionally the document, if the document is not found we will return None
-
-        """
-        from kodexa import KodexaPlatform
-
-        url = f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/contents/{document_id}/content"
-        logger.info(f"Downloading document from {url}")
-        doc = requests.get(
-            url,
-            headers={"x-access-token": KodexaPlatform.get_access_token()})
-        if doc.status_code == 200:
-            return Document.from_msgpack(doc.content)
-        elif doc.status_code == 404:
-            return None
-        else:
-            logger.error("Get document failed [" + doc.text + "], response " + str(doc.status_code))
-            raise Exception("Get document failed [" + doc.text + "], response " + str(doc.status_code))
-
-    def get_source(self, document_id: str):
-        """Gets the source for a given document ID from the document store, as per the connector protocol
-
-        Args:
-          document_id: document id for which you what the source
-          document_id: str: 
-
-        Returns:
-          either the source content (byte-array) or None if the document doesn't exist
-
-        """
-        from kodexa import KodexaPlatform
-
-        url = f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/contents/{document_id}/content"
-        logger.info(f"Downloading source from {url}")
-
-        doc = requests.get(
-            url,
-            headers={"x-access-token": KodexaPlatform.get_access_token()})
-
-        if doc.status_code == 200:
-            return doc.content
-        elif doc.status_code == 404:
-            return None
-        else:
-            logger.error("Get document failed [" + doc.text + "], response " + str(doc.status_code))
-            raise Exception("Get document failed [" + doc.text + "], response " + str(doc.status_code))
-
-    def delete(self, document_id: str):
-        """Delete the document with this document ID from the remote document store
-
-        Args:
-          document_id: the ID of the document to delete
-          document_id: str: 
-
-        Returns:
-
-        """
-        from kodexa import KodexaPlatform
-        delete_document_response = requests.delete(
-            f"{KodexaPlatform.get_url()}/api/stores/{self.ref}/contents/{document_id}",
-            headers={"x-access-token": KodexaPlatform.get_access_token()})
-
-        if delete_document_response.status_code == 200:
-            logger.info(f"Deleted document {document_id}")
-        else:
-            logger.error("Delete document failed [" + delete_document_response.text + "], response " + str(
-                delete_document_response.status_code))
-            raise Exception("Delete document failed [" + delete_document_response.text + "], response " + str(
-                delete_document_response.status_code))
-
-    def get_by_path(self, path) -> Optional[Document]:
-        """Return the latest representation document at a given path
-
-        Args:
-          path: the path (i.e. /my-folder/file.pdf)
-
-        Returns:
-          The latest document representation for that path
-
-        """
-        from kodexa import KodexaPlatform
-        import requests
-        resp = requests.get(
-            f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs/{path}",
-            headers={"x-access-token": KodexaPlatform.get_access_token()})
-
-        if resp.status_code == 200:
-            return Document.from_msgpack(resp.content)
-        if resp.status_code == 404:
-            return None
-        else:
-            msg = f"Unable to get file from store at given path - {resp.text} - status : {resp.status_code}"
-            logger.error(msg)
-            raise Exception(msg)
-
-    def put_native(self, path: str, content, force_replace=False):
-        """Push content directly, this will create both a native object in the store and also a
-        related Document that refers to it.
-
-        Args:
-          path: the path where you want to put the native content
-          content: the binary content for the native file
-          force_replace: replace the content at this path completely (Default value = False)
-          path: str: 
-
-        Returns:
-          None
-
-        """
+    def delete(self, path: str):
         from kodexa import KodexaPlatform
         try:
-            import io
+            logger.info(f"Deleting document family at path {path}")
 
-            logger.info(f"Putting document with path {path}")
+            document_family_response = requests.delete(
+                f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs/{path}",
+                headers={"x-access-token": KodexaPlatform.get_access_token()}, )
 
-            files = {"file": content}
-            data = {"path": path, "forceReplace": force_replace}
-            content_object_response = requests.post(
-                f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/contents",
-                headers={"x-access-token": KodexaPlatform.get_access_token()},
-                files=files, data=data)
-
-            if content_object_response.status_code == 200:
-                from addict import Dict
-                content_object = Dict(json.loads(content_object_response.text))
-                return content_object
+            if document_family_response.status_code == 200:
+                return True
             else:
-                logger.error("Execution creation failed [" + content_object_response.text + "], response " + str(
-                    content_object_response.status_code))
-                raise Exception("Execution creation failed [" + content_object_response.text + "], response " + str(
-                    content_object_response.status_code))
+                return False
         except JSONDecodeError:
             logger.error(
-                f"Unable to decode the JSON response")
+                "Unable to decode the JSON response")
             raise
 
-    def put(self, path: str, document: Document, force_replace=False):
-        """Put the document into the document store at the given path, note that if there is already a document
-        at this path then the lineage UUID for this document must related to one of the documents the documents
-        that are held at that path
-
-        Args:
-          path: the path to the document to use
-          document: the document
-          force_replace: this will remove all the representations of the document at this path and replace it with this one (Default value = False)
-          path: str: 
-          document: Document: 
-
-        Returns:
-
-        """
+    def add_related_document_to_family(self, document_family_id: str, transition: DocumentTransition,
+                                       document: Document):
         from kodexa import KodexaPlatform
         try:
-            import io
+            logger.info(f"Putting document to family id {document_family_id}")
 
-            logger.info(f"Putting document with path {path}")
+            data = {'transitionType': str(transition.transition_type),
+                    'sourceContentObjectId': transition.source_content_object_id}
+            files = {"document": document.to_msgpack()}
+            document_family_response = requests.post(
+                f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/families/{document_family_id}/objects",
+                headers={"x-access-token": KodexaPlatform.get_access_token()},
+                data=data,
+                files=files)
+
+            if document_family_response.status_code == 200:
+                return DocumentFamily.from_dict(document_family_response.json())
+            else:
+                msg = "Document family create failed [" + document_family_response.text + "], response " + str(
+                    document_family_response.status_code)
+                logger.error(msg)
+                raise Exception(msg)
+        except JSONDecodeError:
+            logger.error(
+                "Unable to decode the JSON response")
+            raise
+
+    def get_document_by_content_object(self, document_family: DocumentFamily, content_object: ContentObject) -> \
+            Optional[Document]:
+        get_response = self._base_get(
+            f"api/stores/{self.ref.replace(':', '/')}/families/{document_family.id}/objects/{content_object.id}/content")
+        return Document.from_msgpack(get_response.content) if get_response is not None else None
+
+    def get_source_by_content_object(self, document_family: DocumentFamily, content_object: ContentObject) -> \
+            Any:
+        get_response = self._base_get(
+            f"api/stores/{self.ref.replace(':', '/')}/families/{document_family.id}/objects/{content_object.id}/content")
+        return get_response.content if get_response is not None else None
+
+    def register_listener(self, listener):
+        pass
+
+    def query_families(self, query: str = "*", page: int = 1, page_size: int = 100) -> List[DocumentFamily]:
+        params = {
+            'page': page,
+            'pageSize': page_size,
+            'query': query
+        }
+        get_response = self._base_get(f"api/stores/{self.ref.replace(':', '/')}/families", params=params)
+        if get_response is not None:
+            families = []
+            for fam_dict in get_response.json()['content']:
+                families.append(DocumentFamily.from_dict(fam_dict))
+            return families
+        else:
+            return []
+
+    def put(self, path: str, document: Document, force_replace: bool = False) -> DocumentFamily:
+        from kodexa import KodexaPlatform
+        try:
+            logger.info(f"Putting document to path {path}")
 
             files = {"document": document.to_msgpack()}
             data = {"path": path, "forceReplace": force_replace}
-            content_object_response = requests.post(
-                f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/contents",
+            document_family_response = requests.post(
+                f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs/{path}",
                 headers={"x-access-token": KodexaPlatform.get_access_token()},
                 files=files, data=data)
 
-            if content_object_response.status_code == 200:
-                from addict import Dict
-                content_object = Dict(json.loads(content_object_response.text))
+            if document_family_response.status_code == 200:
+                return DocumentFamily.from_dict(document_family_response.json())
             else:
-                logger.error("Execution creation failed [" + content_object_response.text + "], response " + str(
-                    content_object_response.status_code))
-                raise Exception("Execution creation failed [" + content_object_response.text + "], response " + str(
-                    content_object_response.status_code))
+                msg = "Document family create failed [" + document_family_response.text + "], response " + str(
+                    document_family_response.status_code)
+                logger.error(msg)
+                raise Exception(msg)
         except JSONDecodeError:
             logger.error(
-                f"Unable to decode the JSON response")
+                "Unable to decode the JSON response")
             raise
 
-    def get_next_objects(self):
-        """ """
-        from kodexa import KodexaPlatform
-        content_objects_response = requests.get(
-            f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/contents",
-            params={"query": self.query, "page": self.page, "pageSize": 20},
-            headers={"x-access-token": KodexaPlatform.get_access_token()})
+    def get_family_by_path(self, path: str) -> Optional[DocumentFamily]:
+        get_response = self._base_get(f"api/stores/{self.ref.replace(':', '/')}/fs/{path}", params={"meta": True})
+        return DocumentFamily.from_dict(get_response.json()) if get_response is not None else None
 
-        if content_objects_response.status_code != 200:
-            raise Exception(
-                f"Exception occurred while trying to fetch objects [{content_objects_response.status_code}]")
+    def count(self) -> int:
+        get_response = self._base_get(f"api/stores/{self.ref.replace(':', '/')}/families")
+        if get_response is not None:
+            return get_response.json()['totalElements']
         else:
-            self.objects = content_objects_response.json()['content']
+            return 0
 
-    def query_objects(self, query: str, sort_by=None, sort_direction='asc') -> List[ContentObject]:
-        """Query the documents in the given document store and a list of the document metadata matches
+    def get_by_content_object_id(self, document_family: DocumentFamily, content_object_id: str) -> Optional[Document]:
+        get_response = self._base_get(
+            f"api/stores/{self.ref.replace(':', '/')}/families/{document_family.id}/objects/{content_object_id}/content")
+        if get_response is not None:
+            return Document.from_msgpack(get_response.content)
+        else:
+            return None
 
-        Args:
-          sort_direction: the sort direction (either asc - ascending or desc - descending) (Default value = 'asc')
-          sort_by: the name of the metadata field to sort by (ie. createdDate) (Default value = None)
-          query: A lucene style query for the metadata in the document store
-          query: str: 
-
-        Returns:
-          A list of content objects
-
-        """
+    def _base_get(self, api_path: str, params: Optional[dict] = None) -> Optional[Response]:
+        if params is None:
+            params = {}
         from kodexa import KodexaPlatform
-        params = {'query': query}
-        if sort_by is not None:
-            params['sortBy'] = sort_by
-            params['sortDesc'] = sort_direction
 
-        print(query)
-        print(f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/contents")
-        list_content = requests.get(
-            f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/contents",
+        url = f"{KodexaPlatform.get_url()}/{api_path}"
+        logger.info(f"Accessing {url}")
+
+        get_response = requests.get(
+            url,
             params=params,
             headers={"x-access-token": KodexaPlatform.get_access_token()})
-        if list_content.status_code != 200:
-            raise Exception(
-                f"Exception occurred while trying to fetch objects [{list_content.status_code}]")
-        results: List[ContentObject] = []
-        for co_dict in list_content.json()['content']:
-            results.append(ContentObject.from_dict(co_dict))
-        return results
 
-    def list_objects(self) -> List[ContentObject]:
-        """List the objects in the remote document store
-        
-        :return: a list of the dictionaries containing the metadata for the documents in the store
-
-        Args:
-
-        Returns:
-
-        """
-        from kodexa import KodexaPlatform
-        list_content = requests.get(
-            f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/contents",
-            headers={"x-access-token": KodexaPlatform.get_access_token()})
-        if list_content.status_code != 200:
-            raise Exception(
-                f"Exception occurred while trying to fetch objects [{list_content.status_code}]")
-
-        results: List[ContentObject] = []
-        for co_dict in list_content.json()['content']:
-            results.append(ContentObject.from_dict(co_dict))
-        return results
-
-    def __iter__(self):
-        return self
-
-    def __next__(self):
-
-        if self.objects is None:
-            self.objects = self.query_objects(self.query_string)
-
-        if len(self.objects) == 0:
-            raise StopIteration
+        if get_response.status_code == 200:
+            return get_response
+        elif get_response.status_code == 404:
+            return None
         else:
-            content_object = self.objects.pop(0)
-
-            if content_object['content_type'] == "DOCUMENT":
-                return self.get(content_object['id'])
-
-            raise StopIteration
+            msg = "Get failed [" + get_response.text + "], response " + str(get_response.status_code)
+            logger.error(msg)
+            raise Exception(msg)
 
 
 class RemoteModelStore(ModelStore, RemoteStore):
-    """ """
+    """
+    A remote model store allows you to store artifacts from your model
+    """
 
     def to_dict(self):
         """ """
@@ -576,23 +423,21 @@ class RemoteModelStore(ModelStore, RemoteStore):
         self.ref = ref
 
     def get_ref(self) -> str:
-        """Get the reference to the store on the platform (i.e. kodexa/my-store:1.1.0)
-        
-        :return: The reference
-
-        Args:
+        """
+        Get the reference to the store on the platform (i.e. kodexa/my-store:1.1.0)
 
         Returns:
-
+            The reference to the store
         """
         return self.ref
 
     def delete(self, object_path: str):
-        """Delete the content stored in the model store at the given path
+        """
+        Delete the content stored in the model store at the given path
 
         Args:
           object_path: the path to the content (ie. mymodel.dat)
-          object_path: str: 
+          object_path: str:
 
         Returns:
           True if deleted, False if there was no file at the path
@@ -618,7 +463,7 @@ class RemoteModelStore(ModelStore, RemoteStore):
 
         Args:
           object_path: the object path
-          object_path: str: 
+          object_path: str:
 
         Returns:
           the bytes or None is nothing is at the path
@@ -637,14 +482,14 @@ class RemoteModelStore(ModelStore, RemoteStore):
             logger.error(msg)
             raise Exception(msg)
 
-    def put(self, path: str, content, force_replace=False):
+    def put(self, path: str, content, force_replace=False) -> ContentObject:
         """Put the content into the model store at the given path
 
         Args:
           path: The path you wish to put the content at
           content: The content for that object
           force_replace: overwrite the existing object if it is there (defaulted to False)
-          path: str: 
+          path: str:
 
         Returns:
 
@@ -652,8 +497,6 @@ class RemoteModelStore(ModelStore, RemoteStore):
         from kodexa import KodexaPlatform
         import requests
         try:
-            import io
-
             files = {"file": content}
             data = {"path": path, "forceReplace": force_replace}
             content_object_response = requests.post(
@@ -662,19 +505,19 @@ class RemoteModelStore(ModelStore, RemoteStore):
                 files=files, data=data)
 
             if content_object_response.status_code == 200:
-                from addict import Dict
-                content_object = Dict(json.loads(content_object_response.text))
+                return ContentObject.from_dict(content_object_response.json())
             elif content_object_response.status_code == 400:
                 from addict import Dict
                 bad_request = Dict(json.loads(content_object_response.text))
                 for error_key in bad_request.errors.keys():
                     print(bad_request.errors[error_key] + " (" + error_key + ")")
+                raise Exception("Invalid request")
             else:
-                logger.error("Execution creation failed [" + content_object_response.text + "], response " + str(
-                    content_object_response.status_code))
-                raise Exception("Execution creation failed [" + content_object_response.text + "], response " + str(
-                    content_object_response.status_code))
+                msg = "Execution creation failed [" + content_object_response.text + "], response " + str(
+                    content_object_response.status_code)
+                logger.error(msg)
+                raise Exception(msg)
         except JSONDecodeError:
             logger.error(
-                f"Unable to JSON decode the response?")
+                "Unable to JSON decode the response?")
             raise
