@@ -1,7 +1,4 @@
-from typing import List
-
-from kodexa import Assistant, Pipeline, AssistantContext
-from kodexa.model.document_families import ContentEvent
+from kodexa import Assistant, AssistantContext, AssistantResponse, ContentEvent, Pipeline
 
 
 class TestAction:
@@ -18,11 +15,11 @@ class TestAction:
 class TestAssistant(Assistant):
     """ """
 
-    def process_event(self, event: ContentEvent, context: AssistantContext = None) -> List[Pipeline]:
+    def process_event(self, event: ContentEvent, context: AssistantContext = None) -> AssistantResponse:
         """
 
         Args:
-          event: ContentEvent: 
+          event: ContentEvent:
           context: AssistantContext:  (Default value = None)
 
         Returns:
@@ -35,4 +32,4 @@ class TestAssistant(Assistant):
         pipeline = Pipeline()
         pipeline.add_label('hello')
 
-        return [pipeline]
+        return AssistantResponse([pipeline])
