@@ -1,13 +1,12 @@
 import errno
 import importlib
 import logging
-from typing import cast, List
+from typing import List, cast
 
 from addict import Dict, addict
 
-from kodexa import LocalDocumentStore, Assistant
-from kodexa import PipelineContext, TableDataStore, Document, ContentNode
-from kodexa.model.document_families import ContentEvent, DocumentTransition, DocumentActor
+from kodexa import Assistant, AssistantResponse, LocalDocumentStore
+from kodexa import ContentNode, Document, PipelineContext, TableDataStore,  ContentEvent, DocumentActor, DocumentTransition, TransitionType
 from kodexa.model.model import DocumentStore
 
 logger = logging.getLogger('kodexa.testing')
@@ -18,8 +17,8 @@ def print_data_table(context: PipelineContext, store_name: str):
 
     Args:
       context: param store_name:
-      context: PipelineContext: 
-      store_name: str: 
+      context: PipelineContext:
+      store_name: str:
 
     Returns:
 
@@ -43,9 +42,9 @@ def snapshot_store(context: PipelineContext, store_name: str, filename: str):
       context: the pipeline context
       store_name: the name of the store
       filename: the name of the file to snapshot the store to
-      context: PipelineContext: 
-      store_name: str: 
-      filename: str: 
+      context: PipelineContext:
+      store_name: str:
+      filename: str:
 
     Returns:
 
@@ -60,7 +59,7 @@ def simplify_node(node: ContentNode):
     """
 
     Args:
-      node: ContentNode: 
+      node: ContentNode:
 
     Returns:
 
@@ -79,7 +78,7 @@ def simplify_document(document: Document) -> Dict:
     """
 
     Args:
-      document: Document: 
+      document: Document:
 
     Returns:
 
@@ -93,8 +92,8 @@ def compare_document(document: Document, filename: str, throw_exception=True):
     """
 
     Args:
-      document: Document: 
-      filename: str: 
+      document: Document:
+      filename: str:
       throw_exception:  (Default value = True)
 
     Returns:
@@ -143,9 +142,9 @@ def compare_store(context: PipelineContext, store_name: str, filename: str, thro
       store_name: the name of the store
       filename: the filename of the
       throw_exception: throw an exception if there is a mismatch (Default value = True)
-      context: PipelineContext: 
-      store_name: str: 
-      filename: str: 
+      context: PipelineContext:
+      store_name: str:
+      filename: str:
 
     Returns:
 
@@ -221,6 +220,7 @@ class AssistantTestHarness:
     >>> harness = util.get_assistant("my-assistant", stores=[my_local_store])
 
     """
+
     def __init__(self, assistant: Assistant, stores: List[DocumentStore]):
         """
         Initialize the test harness
@@ -243,35 +243,37 @@ class AssistantTestHarness:
 
         Args:
           event: content event
-          event: ContentEvent: 
+          event: ContentEvent:
 
         Returns:
           None
 
         """
 
-        pipelines = self.assistant.process_event(event)
+        response: AssistantResponse = self.assistant.process_event(event)
 
         # We need to get the document down
         store = self.get_store(event)
 
-        for pipeline in pipelines:
-            pipeline.connector = [store.get_document_by_content_object(event.content_object)]
-            pipeline_context = pipeline.run()
+        for pipeline in response.pipelines:
+            document = store.get_document_by_content_object(event.document_family, event.content_object)
+            if document is not None:
+                pipeline.connector = [document]
+                pipeline_context = pipeline.run()
 
-            if pipeline_context.output_document is not None:
-                # We need to build the transition between the old and the new
-                document_relationship = DocumentTransition("DERIVED", event.content_object.id, None,
-                                                           DocumentActor("testing", "assistant"))
+                if pipeline_context.output_document is not None:
+                    # We need to build the transition between the old and the new
+                    document_relationship = DocumentTransition(TransitionType.DERIVED, event.content_object.id, None,
+                                                               DocumentActor("testing", "assistant"))
 
-                store.add_related_document_to_family(event.document_family.id, document_relationship,
-                                                     pipeline_context.output_document)
+                    store.add_related_document_to_family(event.document_family.id, document_relationship,
+                                                         pipeline_context.output_document)
 
-            # We need to handle the context here, basically we are going to take the result
-            # of the pipeline as a new document and add it to the family?? think about that?
+                # We need to handle the context here, basically we are going to take the result
+                # of the pipeline as a new document and add it to the family?? think about that?
 
-            # so does the assistant decide to write to the store? or do we just do it anyway?
-            # how does the assistant know what happened to the pipeline?
+                # so does the assistant decide to write to the store? or do we just do it anyway?
+                # how does the assistant know what happened to the pipeline?
 
         pass
 
@@ -280,7 +282,7 @@ class AssistantTestHarness:
         Register a local document store with this harness
 
         Args:
-          store: LocalDocumentStore: 
+          store: LocalDocumentStore:
 
         Returns:
 
@@ -292,7 +294,7 @@ class AssistantTestHarness:
         Get a document store for the event (based on the document family ID)
 
         Args:
-          event: ContentEvent: 
+          event: ContentEvent:
 
         Returns:
           The instance of the document store
@@ -336,7 +338,7 @@ class ExtensionPackUtil:
         """
 
         Args:
-          action_slug: 
+          action_slug:
           options:  (Default value = None)
 
         Returns:
